summaryrefslogtreecommitdiffstats
path: root/kfile-plugins/torrent/bdict.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
commit47c8a359c5276062c4bc17f0e82410f29081b502 (patch)
tree2d54a5f60a5b74067632f9ef6df58c2bc38155e6 /kfile-plugins/torrent/bdict.h
parent6f82532777a35e0e60bbd2b290b2e93e646f349b (diff)
downloadtdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.tar.gz
tdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1157648 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kfile-plugins/torrent/bdict.h')
-rw-r--r--kfile-plugins/torrent/bdict.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/kfile-plugins/torrent/bdict.h b/kfile-plugins/torrent/bdict.h
index 4722b9ec..77516c7f 100644
--- a/kfile-plugins/torrent/bdict.h
+++ b/kfile-plugins/torrent/bdict.h
@@ -19,14 +19,14 @@
#ifndef _BDICT_H
#define _BDICT_H
-#include <qdict.h>
-#include <qcstring.h> // QByteArray
+#include <tqdict.h>
+#include <tqcstring.h> // QByteArray
#include "bytetape.h"
#include "bbase.h"
// Some useful typedefs
-typedef QDict<BBase> BBaseHash;
-typedef QDictIterator<BBase> BBaseHashIterator;
+typedef TQDict<BBase> BBaseHash;
+typedef TQDictIterator<BBase> BBaseHashIterator;
// Forward declarations
class BInt;
@@ -53,7 +53,7 @@ class BDict : public BBase
* @param dict the buffer containing the b-encoded dictionary
* @param start the position of the data within the buffer
*/
- BDict (QByteArray &dict, int start = 0);
+ BDict (TQByteArray &dict, int start = 0);
/**
* Construct a dictionary from a ByteTape. The data and current
@@ -166,17 +166,17 @@ class BDict : public BBase
/**
* Outputs the b-encoded representation of the object to the given
* QIODevice.
* @param device the QIODevice to write to
* @return true on a successful write, false otherwise
*/
- virtual bool writeToDevice (QIODevice &device);
+ virtual bool writeToDevice (TQIODevice &device);
/**
* Returns a QDictIterator<BBase> that you can use to iterate through
* the items in the dictionary.
*
* @return QDictIterator<BBase>, which can be used to iterate through
* the items in the dictionary.
*/
BBaseHashIterator iterator() const
@@ -194,7 +194,7 @@ class BDict : public BBase
*/
void init (ByteTape &tape);
- BBaseHash m_map; /// The QDict that actually store the data
+ BBaseHash m_map; /// The TQDict that actually store the data
bool m_valid; /// Store initialization status
};
@@ -166,17 +166,17 @@ class BDict : public BBase
/**
* Outputs the b-encoded representation of the object to the given
- * QIODevice.
- * @param device the QIODevice to write to
+ * TQIODevice.
+ * @param device the TQIODevice to write to
* @return true on a successful write, false otherwise
*/
@@ -166,17 +166,17 @@ class BDict : public BBase
/**
- * Returns a QDictIterator<BBase> that you can use to iterate through
+ * Returns a TQDictIterator<BBase> that you can use to iterate through
* the items in the dictionary.
*
@@ -166,17 +166,17 @@ class BDict : public BBase
* the items in the dictionary.
*
- * @return QDictIterator<BBase>, which can be used to iterate through
+ * @return TQDictIterator<BBase>, which can be used to iterate through
* the items in the dictionary.
*/